@@ -202,13 +202,13 @@ class ReconnectingWebSocket:
             try:
                 res = await asyncio.wait_for(self.ws.receive(), timeout=self.TIMEOUT)
             except asyncio.TimeoutError:
-                logging.debug(f"no message in {self.TIMEOUT} seconds")
+                logging.error(f"no message in {self.TIMEOUT} seconds")
             except asyncio.CancelledError as e:
-                logging.debug(f"cancelled error {e}")
+                logging.error(f"cancelled error {e}")
             except asyncio.IncompleteReadError as e:
-                logging.debug(f"incomplete read error {e}")
+                logging.error(f"incomplete read error {e}")
             except Exception as e:
-                logging.debug(f"exception {e}")
+                logging.error(f"exception {e}")
             else:
                 res = self._handle_message(res)
 
@@ -293,12 +293,12 @@ class HuoBiWebSocketManager:
     USDT_MARGINED_MARKET = "linear-swap-ws"
     USDT_MARGINED_ORDER = "linear-swap-notification"
 
-    INDEX_DATA = "ws_index" # 指数/基差
+    INDEX_DATA = "ws_index"     # 指数/基差
     SYSTEM_STATUS = "center-notification"
 
     def __init__(self, api_key: Optional[str] = None, api_secret: Optional[str] = None, proxy=None):
         self.proxy = proxy
-        self.ws: ReconnectingWebSocket = None
+        self.ws: Optional[ReconnectingWebSocket] = None
         self._api_key = api_key
         self._api_secret = api_secret
         self._create_ws = partial(ReconnectingWebSocket, proxy=self.proxy, api_key=api_key, api_secret=api_secret)
